==> dde-session-shell_5.5.34.orig.tar.xz: dde-session-shell-5.5.34/translations/dde-session-shell_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Yüz Kimliği </translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama başarılı</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama başarısız oldu, sadece bir şans kaldı</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Yüz ve İris Kimliğinizi doğrulayın</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Yüz kimliği kilitli, şifreyi kullanın lütfen</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Parmak izinizi doğrulayın</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama başarılı</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama başarısız oldu, sadece bir şans kaldı</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Parmak izi kilitli, lütfen parola kullanın</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>İris Kimliği </translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama başarılı</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama başarısız oldu, sadece bir şans kaldı</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Iris Kimliğinizi doğrulayın</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>İris kimliği kilitli, şifreyi kullanın lütfen</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama başarılı</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama başarısız oldu, sadece bir şans kaldı</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Yanlış Parola</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Lütfen 1 dakika sonra tekrar deneyin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Lütfen %n dakika sonra tekrar deneyin</numerusform><numerusform>Lütfen %n dakika sonra tekrar deneyin</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Parolayı Sıfırla</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Parolanızı mı unuttunuz?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Lütfen 1 dakika sonra tekrar deneyin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Lütfen %n dakika sonra tekrar deneyin</numerusform><numerusform>Lütfen %n dakika sonra tekrar deneyin</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Parolayı Sıfırla</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Parolanızı mı unuttunuz?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama başarılı</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama başarısız oldu, sadece bir şans kaldı</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Yanlış PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey gerekli</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>PIN&apos;inizi girin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Lütfen %n dakika(s) sonra tekrar deneyin</numerusform><numerusform>Lütfen %n dakika(s) sonra tekrar deneyin</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Lütfen 1 dakika sonra tekrar deneyin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Lütfen %n dakika sonra tekrar deneyin</numerusform><numerusform>Lütfen %n dakika sonra tekrar deneyin</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Hesap</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>Parolanızın süresi %n gün içinde dolacak, lütfen zamanında değiştirin </numerusform><numerusform>Parolanızın süresi %n gün içinde dolacak, lütfen zamanında değiştirin </numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Parolanın süresi doldu, lütfen değiştir</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Yanlış hesap</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Yanlış Parola</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Ekranı Kilitle</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Ekran kilitlenemedi</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Parmak izi doğrulama zaman aşımına uğradı, lütfen parolanızı elle girin</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Parmak izi eşleştirilemedi</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Yukarıdaki kullanıcılar oturum açmış durumda ve kapatma nedeniyle veriler kaybedilecek, kapatmak istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Yukarıdaki kullanıcıların oturumu açık ve yeniden başlatılınca veriler kaybolacak, yeniden başlatmak istediğinize emin misiniz?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Yüksek sistem güvenlik seviyesini etkinleştirdiniz, bu nedenle Wayland kipine geçemezsiniz, lütfen Güvenlik Merkezi&apos;nde yüksek güvenlik seviyesini devre dışı bırakın ve tekrar deneyin.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Askıya al</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Uyut</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kilitle</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Oturumu kapat</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Kullanıcı değiştir</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Sistem değiştir</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Sistem izleyiciyi başlat</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Programlar bilgisayarın kapanmasını önlüyor ve kapanmaya zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Programı kapatmak için İptal&apos;i tıklayın ve ardından programı kapatın.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Programlar bilgisayarın yeniden başlatılmasını engelliyor ve yeniden başlatmayı zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Programlar bilgisayarın askıya alınmasını önlüyor ve askıya almayı zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Programlar bilgisayarın hazırda bekletme kipine geçmesini engelliyor ve hazırda bekletme kipini zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Programlar, bilgisayarın oturumu kapatmasını engelliyor ve oturumu kapatmak zorla veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Askıya al</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Uyut</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Oturumu kapat</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Kapatmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Yeniden başlatmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Oturumu kapatmak istediğinize emin misiniz?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Kapat</translation>
    </message>
</context>
</TS>

==> dde-session-shell_5.5.100.2.orig.tar.xz: dde-session-shell-5.5.100.2/translations/dde-session-shell_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Yüz Kimliği </translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama başarılı</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama başarısız oldu, sadece bir şans kaldı</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Yüz ve İris Kimliğinizi doğrulayın</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Yüz kimliği kilitli, şifreyi kullanın lütfen</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Cihaz erişilemez!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Parmak izinizi doğrulayın</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama başarılı</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama başarısız oldu, sadece bir şans kaldı</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Parmak izi kilitli, lütfen parola kullanın</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>İris Kimliği </translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama başarılı</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama başarısız oldu, sadece bir şans kaldı</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Iris Kimliğinizi doğrulayın</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>İris kimliği kilitli, şifreyi kullanın lütfen</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama başarılı</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama başarısız oldu, sadece bir şans kaldı</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Yanlış Parola</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Lütfen 1 dakika sonra tekrar deneyin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Parolayı Sıfırla</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Parolanızı mı unuttunuz?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Lütfen 1 dakika sonra tekrar deneyin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Lütfen %n dakika sonra tekrar deneyin</numerusform><numerusform>Lütfen %n dakika sonra tekrar deneyin</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Parolayı Sıfırla</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Parolanızı mı unuttunuz?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama başarılı</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama başarısız oldu, sadece bir şans kaldı</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Yanlış PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey gerekli</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>PIN&apos;inizi girin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Lütfen %n dakika(s) sonra tekrar deneyin</numerusform><numerusform>Lütfen %n dakika(s) sonra tekrar deneyin</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Lütfen 1 dakika sonra tekrar deneyin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Hesap</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Parolanın süresi doldu, lütfen değiştir</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Yanlış hesap</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Yanlış Parola</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Ekranı Kilitle</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Ekran kilitlenemedi</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Parmak izi doğrulama zaman aşımına uğradı, lütfen parolanızı elle girin</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Parmak izi eşleştirilemedi</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Yukarıdaki kullanıcılar oturum açmış durumda ve kapatma nedeniyle veriler kaybedilecek, kapatmak istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Yukarıdaki kullanıcıların oturumu açık ve yeniden başlatılınca veriler kaybolacak, yeniden başlatmak istediğinize emin misiniz?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Yüksek sistem güvenlik seviyesini etkinleştirdiniz, bu nedenle Wayland kipine geçemezsiniz, lütfen Güvenlik Merkezi&apos;nde yüksek güvenlik seviyesini devre dışı bırakın ve tekrar deneyin.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Askıya al</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Uyut</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kilitle</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Oturumu kapat</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Kullanıcı değiştir</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Sistem değiştir</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Sistem izleyiciyi başlat</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Programlar bilgisayarın kapanmasını önlüyor ve kapanmaya zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Programı kapatmak için İptal&apos;i tıklayın ve ardından programı kapatın.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Programlar bilgisayarın yeniden başlatılmasını engelliyor ve yeniden başlatmayı zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Programlar bilgisayarın askıya alınmasını önlüyor ve askıya almayı zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Programlar bilgisayarın hazırda bekletme kipine geçmesini engelliyor ve hazırda bekletme kipini zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Programlar, bilgisayarın oturumu kapatmasını engelliyor ve oturumu kapatmak zorla veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Askıya al</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Uyut</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Oturumu kapat</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Kapatmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Yeniden başlatmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Oturumu kapatmak istediğinize emin misiniz?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Kapat</translation>
    </message>
</context>
</TS>
